@@ -64,26 +64,27 @@ var NAVTREEINDEX =
 "alloc_8h.html",
 "group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0",
 "group__pw__global.html#ga7c5ab037320ab252af6eb6eb1b85b0b9",
-"group__pw__keys.html#ga94975808271e28be225a6fd6d7957762",
-"group__pw__node.html#ga13f0cb22b45e8f81e709b84ff3b1fde7",
-"group__pw__session__manager.html#ga0b0bc42cc601ef5c82090d463694b5c2",
-"group__pw__work__queue.html#ga56673e78071d8a9eb28805331c8b2245",
-"group__spa__cpu.html#gaabed68d3b3d4db276c57891df69fbc93",
-"group__spa__json.html#ga4dbbb0d8d43216c23d20b08be1650437",
-"group__spa__names.html#gac4ef8bddd1f53a3a890c5ab7bb32db3f",
-"group__spa__param.html#ga4077adc9cb334bd78d561f96c04eebbc",
-"group__spa__param.html#gga24bd9414a34ba30e9c0f0ad99b86e427ad6c7dc4e62838af48f2451c84e53d7fa",
-"group__spa__param.html#gga99c6341a3416bdaacc42f77fc4869821a4ba324c410f312d2561dffb47e9af99b",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea91b3097e817b6334a4e50614fa64ede5",
-"group__spa__pod.html#gaa5ae3c08bb5f3e90e5b0688c5668e002",
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635af25926b5d489ddd2acb63ea263c78e92",
-"page_module_metadata.html",
-"structpw__client__endpoint__events.html#a02d8f4d9cd9f898d3109a64f7afd81e1",
-"structpw__impl__factory__events.html",
-"structpw__proxy__events.html",
-"structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724",
-"structspa__loop__methods.html#ae7dc5184539a2425309dee69d2867dcf",
-"structspa__source.html"
+"group__pw__keys.html#ga920ad1d3f16b5fe42e001aab2af08680",
+"group__pw__node.html#ga125b3c8bae9656635dd9c24febbe221f",
+"group__pw__session__manager.html#ga0a2fbf1e9c6493db2e61e629647dda82",
+"group__pw__work__queue.html#ga528c2be5bb8ef21bdbe8bfa44485f8bb",
+"group__spa__cpu.html#gaab2a78075bf054d09f7e950150278b8b",
+"group__spa__json.html#ga0d0d13b703fb3bf42b6a96b11973767a",
+"group__spa__names.html#ga9d31cf5ef1e43bb2f1aca6b3dd07a0fa",
+"group__spa__param.html#ga34f2853a6e1fb9c8600cd3675f48376e",
+"group__spa__param.html#gga15af911097602fc40039042f4d542e87a3979d9964045fd48c076dc1f83951119",
+"group__spa__param.html#gga8aac121d9e3a588a30d970526fd556dda124cfca5319dc552b3364f1d4ddce452",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea7928095dd38a36fbf6819d61199cf5e2",
+"group__spa__pod.html#ga9c600d17cc240567be847b7f5f586bee",
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ab0d0e30c07c9d934c96bc2210183537b",
+"page_module_avb.html",
+"page_spa_pod.html#autotoc_md255",
+"structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a",
+"structpw__memblock.html#a8e96a2d24a5fc723b2a637de4bf700b1",
+"structspa__audio__aec__methods.html#a73977fea4b6c069260af4f16b08ceee0",
+"structspa__hook.html",
+"structspa__pod__bitmap.html",
+"tutorial4_8c-example.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
