@@ -1,5 +1,6 @@
 var NAVTREEINDEX5 =
 {
+"group__pw__session__manager.html#ga0a2fbf1e9c6493db2e61e629647dda82":[10,7,4,78],
 "group__pw__session__manager.html#ga0b0bc42cc601ef5c82090d463694b5c2":[10,7,4,175],
 "group__pw__session__manager.html#ga1069edd0047bbb473360862df48e2919":[10,7,4,123],
 "group__pw__session__manager.html#ga10c31c04d8ed4a8f4670a35af75e8caa":[10,7,4,30],
@@ -248,6 +249,5 @@ var NAVTREEINDEX5 =
 "group__pw__utils.html#gacdc181bb9d9a0be73f19ad2745630399":[10,6,8,6],
 "group__pw__utils.html#gae06596c091a3ae4ddd2b262deec5bd34":[10,6,8,2],
 "group__pw__work__queue.html":[10,5,16],
-"group__pw__work__queue.html#ga31cc6b38eda61a244c7d3fd9024a74db":[10,5,16,5],
-"group__pw__work__queue.html#ga528c2be5bb8ef21bdbe8bfa44485f8bb":[10,5,16,2]
+"group__pw__work__queue.html#ga31cc6b38eda61a244c7d3fd9024a74db":[10,5,16,5]
 };
