@@ -10,19 +10,19 @@ var searchData=
   ['bind_7',['bind',['../structpw__registry__methods.html#a743174c4df93282f1361f137383cb41a',1,'pw_registry_methods']]],
   ['bitmap_5foffset_8',['bitmap_offset',['../structspa__meta__cursor.html#a9785c5b1408d2d4c4cc053bfb67ef6c0',1,'spa_meta_cursor']]],
   ['bitorder_9',['bitorder',['../structspa__audio__info__dsd.html#a698a141255b6d57f04d56de0fa52d170',1,'spa_audio_info_dsd']]],
-  ['bitrate_10',['bitrate',['../structspa__audio__info__aac.html#a3b08334e341344e0035a7ee94a5c87a2',1,'spa_audio_info_aac::bitrate()'],['../structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2',1,'spa_audio_info_wma::bitrate()']]],
+  ['bitrate_10',['bitrate',['../structspa__audio__info__aac.html#a3b08334e341344e0035a7ee94a5c87a2',1,'spa_audio_info_aac::bitrate'],['../structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2',1,'spa_audio_info_wma::bitrate']]],
   ['block_11',['block',['../structpw__memmap.html#ae80282a00a02c34be7f36975ea52768b',1,'pw_memmap']]],
   ['block_5falign_12',['block_align',['../structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55',1,'spa_audio_info_wma']]],
-  ['body_13',['body',['../structspa__pod__sequence.html#ad699555cf7c8114347524399f2a8b163',1,'spa_pod_sequence::body()'],['../structspa__pod__pointer.html#a09512c2a62eecc6518a7921d4cb0c2a7',1,'spa_pod_pointer::body()'],['../structspa__pod__object.html#a5432f079d6ffcb0d2f0baee8a130219a',1,'spa_pod_object::body()'],['../structspa__pod__choice.html#aa9927ee9a4a320384560480e1783705c',1,'spa_pod_choice::body()'],['../structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb',1,'spa_event::body()'],['../structspa__event__body.html#aa484bc2cadd16a104476183666de3819',1,'spa_event_body::body()'],['../structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e',1,'spa_command::body()'],['../structspa__command__body.html#ab477c03f242e4d10ed2a4e7057f52123',1,'spa_command_body::body()'],['../structspa__pod__array.html#a30a4ff74b448da3df862a7bdb20dad04',1,'spa_pod_array::body()']]],
+  ['body_13',['body',['../structspa__pod__sequence.html#ad699555cf7c8114347524399f2a8b163',1,'spa_pod_sequence::body'],['../structspa__pod__pointer.html#a09512c2a62eecc6518a7921d4cb0c2a7',1,'spa_pod_pointer::body'],['../structspa__pod__object.html#a5432f079d6ffcb0d2f0baee8a130219a',1,'spa_pod_object::body'],['../structspa__pod__choice.html#aa9927ee9a4a320384560480e1783705c',1,'spa_pod_choice::body'],['../structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb',1,'spa_event::body'],['../structspa__event__body.html#aa484bc2cadd16a104476183666de3819',1,'spa_event_body::body'],['../structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e',1,'spa_command::body'],['../structspa__command__body.html#ab477c03f242e4d10ed2a4e7057f52123',1,'spa_command_body::body'],['../structspa__pod__array.html#a30a4ff74b448da3df862a7bdb20dad04',1,'spa_pod_array::body']]],
   ['bound_14',['bound',['../structpw__proxy__events.html#a8916a9be2fa3763221fdf64f79468d14',1,'pw_proxy_events']]],
   ['bound_5fid_15',['bound_id',['../structpw__core__events.html#aab9b9d3a84837d892a4617c29f03e976',1,'pw_core_events']]],
-  ['bound_5fprops_16',['bound_props',['../structpw__core__events.html#a7e1a9d6c8598cee58b622cf61432769e',1,'pw_core_events::bound_props()'],['../structpw__proxy__events.html#a220d199c1f0a241f1e623686863e8158',1,'pw_proxy_events::bound_props()']]],
+  ['bound_5fprops_16',['bound_props',['../structpw__core__events.html#a7e1a9d6c8598cee58b622cf61432769e',1,'pw_core_events::bound_props'],['../structpw__proxy__events.html#a220d199c1f0a241f1e623686863e8158',1,'pw_proxy_events::bound_props']]],
   ['bpm_17',['bpm',['../structspa__io__segment__bar.html#a5398027b6c636c287b2df47239b6b9e3',1,'spa_io_segment_bar']]],
-  ['buffer_18',['buffer',['../structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090',1,'pw_buffer::buffer()'],['../structspa__strbuf.html#ad1ee23ef60728cefba6d11341da61ef1',1,'spa_strbuf::buffer()'],['../structpw__client__node__buffer.html#a27039caf89b376d354a33d1559e939b3',1,'pw_client_node_buffer::buffer()']]],
+  ['buffer_18',['buffer',['../structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090',1,'pw_buffer::buffer'],['../structspa__strbuf.html#ad1ee23ef60728cefba6d11341da61ef1',1,'spa_strbuf::buffer'],['../structpw__client__node__buffer.html#a27039caf89b376d354a33d1559e939b3',1,'pw_client_node_buffer::buffer']]],
   ['buffer_5fid_19',['buffer_id',['../structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b',1,'spa_io_buffers']]],
   ['buffered_20',['buffered',['../structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff',1,'pw_time']]],
   ['buffers_21',['buffers',['../structpw__buffers.html#adf149a809c1ea9c435ae7439391c87ed',1,'pw_buffers']]],
-  ['builder_22',['builder',['../structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce',1,'spa_result_device_params_data::builder()'],['../structspa__result__node__params__data.html#ad11bffd25122b0ca2fef3ac7c360728c',1,'spa_result_node_params_data::builder()']]],
+  ['builder_22',['builder',['../structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce',1,'spa_result_device_params_data::builder'],['../structspa__result__node__params__data.html#ad11bffd25122b0ca2fef3ac7c360728c',1,'spa_result_node_params_data::builder']]],
   ['busy_5fchanged_23',['busy_changed',['../structpw__impl__client__events.html#a046e956441b5395308c8ff140292dfee',1,'pw_impl_client_events']]],
   ['bw_24',['bw',['../structspa__dll.html#ac3de731c327763f69c44e98224ee1068',1,'spa_dll']]]
 ];
